@@ -1,6 +1,6 @@
 // File: lock.hpp
 //
-// Copyright (c) 2002,2003 
+// Copyright (c) 2002,2003,2011
 // Kevin Atkinson
 //
 // Permission to use, copy, modify, distribute and sell this software
@@ -15,8 +15,13 @@
 #ifndef DISTRIBNET_LOCK__HPP
 #define DISTRIBNET_LOCK__HPP
 
+#include <assert.h>
+
 #include "settings.h"
-#include <pthread.h>
+
+#ifdef USE_POSIX_MUTEX
+#  include <pthread.h>
+#endif
 
 namespace acommon {
 
@@ -54,6 +59,8 @@ namespace acommon {
     Mutex * lock_;
   public:
     Lock(Mutex * l) : lock_(l) {if (lock_) lock_->lock();}
+    void set(Mutex * l) {assert(!lock_); lock_ = l; if (lock_) lock_->lock();}
+    void release() {if (lock_) lock_->unlock(); lock_ = NULL;}
     ~Lock() {if (lock_) lock_->unlock();}
   };
 };
