@@ -10,18 +10,22 @@
 #include "string.hpp"
 #include "error.hpp"
 
+#include "errors.hpp"
+
+#include "ndebug.hpp"
+
 namespace acommon {
 
   // PosibErr<type> is a special Error handling device that will make
   // sure that an error is properly handled.  It is expected to be
-  // used as the return type of the function It will automatitcly
+  // used as the return type of the function It will automatically
   // convert to the "normal" return type however if the normal
   // returned type is accessed and there is an "unhandled" error
   // condition it will abort It will also abort if the object is
   // destroyed with an "unhandled" error condition.  This includes
-  // ignoring the return type of a function returing an error
+  // ignoring the return type of a function returning an error
   // condition.  An error condition is handled by simply checking for
-  // the precence of an error, calling ignore, or taking owenership of
+  // the presence of an error, calling ignore, or taking ownership of
   // the error.
 
   enum WhichErr { PrimErr, SecErr };
@@ -34,11 +38,45 @@ namespace acommon {
   private:
     struct ErrPtr {
       const Error * err;
+#ifndef NDEBUG
       bool handled;
+#endif
       int refcount;
-      ErrPtr(const Error * e) : err(e), handled(false), refcount(1) {}
+      ErrPtr(const Error * e) : err(e), 
+#ifndef NDEBUG
+                                handled(false), 
+#endif
+                                refcount(1) {}
     };
     ErrPtr * err_;
+
+  protected:
+
+    void posib_handle_err() const {
+#ifndef NDEBUG
+      if (err_ && !err_->handled)
+	handle_err();
+#endif
+    }
+
+    void copy(const PosibErrBase & other) {
+      err_ = other.err_;
+      if (err_) {
+	++ err_->refcount;
+      }
+    }
+    void destroy() {
+      if (err_ == 0) return;
+      -- err_->refcount;
+      if (err_->refcount == 0) {
+#ifndef NDEBUG
+	if (!err_->handled)
+	  handle_err();
+#endif
+	del();
+      }
+    }
+
   public:
     PosibErrBase() 
       : err_(0) {}
@@ -62,14 +100,18 @@ namespace acommon {
 	return release();
     }
     void ignore_err() {
+#ifndef NDEBUG
       if (err_ != 0)
 	err_->handled = true;
+#endif
     }
     const Error * get_err() const {
       if (err_ == 0) {
 	return 0;
       } else {
+#ifndef NDEBUG
 	err_->handled = true;
+#endif
 	return err_->err;
       }
     }
@@ -87,7 +129,9 @@ namespace acommon {
 	return false;
       } else {
 	if (err_->err->is_a(e)) {
+#ifndef NDEBUG
 	  err_->handled = true;
+#endif
 	  return true;
 	} else {
 	  return false;
@@ -101,58 +145,47 @@ namespace acommon {
       return set(inf, p1, p2, p3, p4);
     }
 
-    // This should only be called _after_ set is called
-    PosibErrBase & with_file(ParmString fn);
+    // These should only be called _after_ set is called
+    PosibErrBase & with_file(ParmString fn, int lineno = 0);
+    PosibErrBase & with_key(ParmString prefix, ParmString key);
     
     PosibErrBase & set(const ErrorInfo *, 
 		       ParmString, ParmString, ParmString, ParmString);
 
-
-  protected:
-
-    void posib_handle_err() const {
-      if (err_ && !err_->handled)
-	handle_err();
-    }
-
-    void copy(const PosibErrBase & other) {
-      err_ = other.err_;
-      if (err_) {
-	++ err_->refcount;
-      }
-    }
-    void destroy() {
-      if (err_ == 0) return;
-      -- err_->refcount;
-      if (err_->refcount == 0) {
-	if (!err_->handled)
-	  handle_err();
-	del();
-      }
-    }
-
   private:
 
+#ifndef NDEBUG
     void handle_err() const;
+#endif
     Error * release();
     void del();
   };
 
+  template <>
+  class PosibErr<void> : public PosibErrBase
+  {
+  public:
+    PosibErr(const PosibErrBase & other) 
+      : PosibErrBase(other) {}
+
+    PosibErr() {}
+  };
+
   template <typename Ret>
   class PosibErr : public PosibErrBase
   {
   public:
-    PosibErr() {}
+    PosibErr() : data() {}
 
     PosibErr(const PosibErrBase & other) 
-      : PosibErrBase(other) {}
+      : PosibErrBase(other), data() {}
 
     template <typename T>
     PosibErr(const PosibErr<T> & other)
       : PosibErrBase(other), data(other.data) {}
 
     PosibErr(const PosibErr<void> & other)
-      : PosibErrBase(other) {}
+      : PosibErrBase(other), data() {}
 
     PosibErr& operator= (const PosibErr & other) {
       data = other.data;
@@ -166,16 +199,6 @@ namespace acommon {
     Ret data;
   };
 
-  template <>
-  class PosibErr<void> : public PosibErrBase
-  {
-  public:
-    PosibErr(const PosibErrBase & other) 
-      : PosibErrBase(other) {}
-
-    PosibErr() {}
-  };
-
 //
 //
 //
@@ -201,24 +224,23 @@ namespace acommon {
   //
   //
   //
-
-  inline String::String(const PosibErr<String> & other)
-    : std::string(other.data) {}
-
   inline String & String::operator= (const PosibErr<const char *> & s)
   {
-    std::string::operator=(s.data);
+    *this = s.data;
     return *this;
   }
 
-  //inline String & String::operator= (const PosibErr<String> & s)
-  //{
-  //  std::string::operator=(s.data);
-  //  return *this;
-  //}
+  inline bool operator== (const PosibErr<String> & x, const char * y)
+  {
+    return x.data == y;
+  }
+  inline bool operator!= (const PosibErr<String> & x, const char * y)
+  {
+    return x.data != y;
+  }
 
   inline ParmString::ParmString(const PosibErr<const char *> & s)
-    : str_(s.data) {}
+    : str_(s.data), size_(UINT_MAX) {}
 
   inline ParmString::ParmString(const PosibErr<String> & s)
     : str_(s.data.c_str()), size_(s.data.size()) {}
