@@ -1,5 +1,5 @@
 // This file is part of The New Aspell Copyright (C)
-// 2002,2003,2004,2011,2019,2023 by Kevin Atkinson
+// 2002,2003,2004,2011,2019,2023,2026 by Kevin Atkinson
 // under the GNU LGPL license version 2.0 or 2.1.  You should have received a
 // copy of the LGPL license along with this library if you did not you can
 // find it at http://www.gnu.org/.
@@ -2881,9 +2881,9 @@ static const unsigned help_text_size = sizeof(help_text)/sizeof(const char *);
 void print_help (bool verbose) {
   load_all_filters(options);
   if (verbose) {
-    printf(_("\n"
-             "Aspell %s.  Copyright 2000-2023 by Kevin Atkinson.\n"
-             "\n"), aspell_version_string());
+    printf("\n"
+           "Aspell %s.  Copyright 2000-2026 by Kevin Atkinson.\n"
+           "\n", aspell_version_string());
     for (unsigned i = 0; i < help_text_size; ++i)
       puts(gt_(help_text[i]));
   } else {
